==> xiaoerke-common-1.0.34-sources.jar: com/cxqm/xiaoerke/modules/sys/service/InviteServiceImpl.java <==
package com.cxqm.xiaoerke.modules.sys.service;

import com.cxqm.xiaoerke.modules.sys.entity.Invite;
import com.cxqm.xiaoerke.modules.sys.entity.SysPropertyVoWithBLOBsVo;
import com.mongodb.WriteResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by sunzb on 2017/10/30.
 */
@Service
@Transactional(readOnly = false)
public class InviteServiceImpl extends MongoDBService<Invite> {

    @Autowired(required = false)
    protected MongoTemplate mongoTemplate;

    @Override
    public int insert(Invite entity) {
        mongoTemplate.insert(entity, "invite");
        return 0;
    }

    @Override
    public int insertByBatch(List<Invite> entities) {
        return 0;
    }

    @Override
    public WriteResult updateMulti(Query query, Update update) {
        return null;
    }

    @Override
    public WriteResult upsert(Query query, Update update) {
        return null;
    }

    @Override
    public int delete(String id) {
        return 0;
    }

    @Override
    public long queryCount(Query query) {
        return 0;
    }

    @Override
    public List<Invite> queryList(Query query) {
        return null;
    }

    @Override
    public List<Invite> queryListDistinct(Query query, String key) {
        return this.mongoTemplate.getCollection("invite").distinct(key, query.getQueryObject());
    }

    public Invite queryInviteProperty(){
        return this.mongoTemplate.find(new Query(), Invite.class, "invite").get(0);
    }

    @Override
    public Invite findAndRemove(Query query) {
        return null;
    }

    @Override
    public List<String> queryStringListDistinct(Query query, String key) {
        return null;
    }

    @Override
    public long mapReduce(String map, String reduce) {
        return 0;
    }
}

==> xiaoerke-common-1.1.11-sources.jar: com/cxqm/xiaoerke/modules/sys/service/InviteServiceImpl.java <==
package com.cxqm.xiaoerke.modules.sys.service;

import com.cxqm.xiaoerke.modules.sys.entity.Invite;
import com.cxqm.xiaoerke.modules.sys.entity.SysPropertyVoWithBLOBsVo;
import com.mongodb.WriteResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by sunzb on 2017/10/30.
 */
@Service
@Transactional(readOnly = false)
public class InviteServiceImpl extends MongoDBService<Invite> {

    @Autowired(required = false)
    protected MongoTemplate mongoTemplate;

    @Override
    public int insert(Invite entity) {
        mongoTemplate.insert(entity, "invite");
        return 0;
    }

    @Override
    public int insertByBatch(List<Invite> entities) {
        return 0;
    }

    @Override
    public WriteResult updateMulti(Query query, Update update) {
        return null;
    }

    @Override
    public WriteResult upsert(Query query, Update update) {
        return null;
    }

    @Override
    public int delete(String id) {
        return 0;
    }

    @Override
    public long queryCount(Query query) {
        return 0;
    }

    @Override
    public List<Invite> queryList(Query query) {
        return null;
    }

    @Override
    public List<Invite> queryListDistinct(Query query, String key) {
        return this.mongoTemplate.getCollection("invite").distinct(key, query.getQueryObject());
    }

    public Invite queryInviteProperty(){
        return this.mongoTemplate.find(new Query(), Invite.class, "invite").get(0);
    }

    public Invite queryInviteDoctorZhyProperty(){
        return this.mongoTemplate.find(new Query(), Invite.class, "inviteDoctorZhy").get(0);
    }

    public Invite queryInviteZhyProperty(){
        return this.mongoTemplate.find(new Query(), Invite.class, "inviteZhy").get(0);
    }

    @Override
    public Invite findAndRemove(Query query) {
        return null;
    }

    @Override
    public List<String> queryStringListDistinct(Query query, String key) {
        return null;
    }

    @Override
    public long mapReduce(String map, String reduce) {
        return 0;
    }
}
